==> surveyplat-proof-common-nfzd-1.0.0-20200930.123212-7-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzWwyh.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2018/5/2.
 * 外网用户表
 */
@Table(name = "dcjz_wwyh")
public class DcjzWwyh {
    @Id
    //主键
    private String wwyhid;

    //用户姓名
    private String yhxm;

    //用户密码
    private String yhmm;

    //任务区
    private String rwq;

    //注册时间
    private Date zcsj;

    //登录时间
    private Date dlsj;

    //手机号
    private String lxdh;

    //工作单位
    private String gzdw;

    //申请说明
    private String sqsm;

    //设备id
    private String sbid;

    //备注
    private String bz;

    //申请状态(0:待审核，1：已通过，2：未通过)
    private String sqzt;

    //在线状态 是否字典表
    private String zxzt;

    //国家注册状态 是否字典表
    private String gjzczt;

    /**
     * 用户编号
     */
    private Integer yhbh;

    //用户是否注销
    private String yhzt;

    //用户角色
    private String yhjs;

    // 实名注册
    private String xm;

    // 身份证号
    private String sfzh;


    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }

    public String getSfzh() {
        return sfzh;
    }

    public void setSfzh(String sfzh) {
        this.sfzh = sfzh;
    }

    public String getYhjs() {
        return yhjs;
    }

    public void setYhjs(String yhjs) {
        this.yhjs = yhjs;
    }

    public Integer getYhbh() {
        return yhbh;
    }

    public void setYhbh(Integer yhbh) {
        this.yhbh = yhbh;
    }

    public String getZxzt() {
        return zxzt;
    }

    public void setZxzt(String zxzt) {
        this.zxzt = zxzt;
    }

    public String getGjzczt() {
        return gjzczt;
    }

    public void setGjzczt(String gjzczt) {
        this.gjzczt = gjzczt;
    }

    public String getSqzt() {
        return sqzt;
    }

    public void setSqzt(String sqzt) {
        this.sqzt = sqzt;
    }

    public String getWwyhid() {
        return wwyhid;
    }

    public void setWwyhid(String wwyhid) {
        this.wwyhid = wwyhid;
    }

    public String getYhxm() {
        return yhxm;
    }

    public void setYhxm(String yhxm) {
        this.yhxm = yhxm;
    }

    public String getYhmm() {
        return yhmm;
    }

    public void setYhmm(String yhmm) {
        this.yhmm = yhmm;
    }

    public String getRwq() {
        return rwq;
    }

    public void setRwq(String rwq) {
        this.rwq = rwq;
    }

    public Date getZcsj() {
        return zcsj;
    }

    public void setZcsj(Date zcsj) {
        this.zcsj = zcsj;
    }

    public Date getDlsj() {
        return dlsj;
    }

    public void setDlsj(Date dlsj) {
        this.dlsj = dlsj;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getGzdw() {
        return gzdw;
    }

    public void setGzdw(String gzdw) {
        this.gzdw = gzdw;
    }

    public String getSqsm() {
        return sqsm;
    }

    public void setSqsm(String sqsm) {
        this.sqsm = sqsm;
    }

    public String getSbid() {
        return sbid;
    }

    public void setSbid(String sbid) {
        this.sbid = sbid;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYhzt() {
        return yhzt;
    }

    public void setYhzt(String yhzt) {
        this.yhzt = yhzt;
    }
}

==> surveyplat-proof-common-nfzd-1.0.0-20211019.031030-14-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzWwyh.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2018/5/2.
 * 外网用户表
 */
@Table(name = "dtxx_wwyh")
public class DcjzWwyh {
    @Id
    //主键
    private String wwyhid;

    //用户姓名
    private String yhxm;

    //用户密码
    private String yhmm;

    //任务区
    private String rwq;

    //注册时间
    private Date zcsj;

    //登录时间
    private Date dlsj;

    //手机号
    private String lxdh;

    //工作单位
    private String gzdw;

    //申请说明
    private String sqsm;

    //设备id
    private String sbid;

    //备注
    private String bz;

    //申请状态(0:待审核，1：已通过，2：未通过)
    private String sqzt;

    //在线状态 是否字典表
    private String zxzt;

    //国家注册状态 是否字典表
    private String gjzczt;

    /**
     * 用户编号
     */
    private Integer yhbh;

    //用户是否注销
    private String yhzt;

    //用户角色
    private String yhjs;

    // 实名注册
    private String xm;

    // 身份证号
    private String sfzh;


    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }

    public String getSfzh() {
        return sfzh;
    }

    public void setSfzh(String sfzh) {
        this.sfzh = sfzh;
    }

    public String getYhjs() {
        return yhjs;
    }

    public void setYhjs(String yhjs) {
        this.yhjs = yhjs;
    }

    public Integer getYhbh() {
        return yhbh;
    }

    public void setYhbh(Integer yhbh) {
        this.yhbh = yhbh;
    }

    public String getZxzt() {
        return zxzt;
    }

    public void setZxzt(String zxzt) {
        this.zxzt = zxzt;
    }

    public String getGjzczt() {
        return gjzczt;
    }

    public void setGjzczt(String gjzczt) {
        this.gjzczt = gjzczt;
    }

    public String getSqzt() {
        return sqzt;
    }

    public void setSqzt(String sqzt) {
        this.sqzt = sqzt;
    }

    public String getWwyhid() {
        return wwyhid;
    }

    public void setWwyhid(String wwyhid) {
        this.wwyhid = wwyhid;
    }

    public String getYhxm() {
        return yhxm;
    }

    public void setYhxm(String yhxm) {
        this.yhxm = yhxm;
    }

    public String getYhmm() {
        return yhmm;
    }

    public void setYhmm(String yhmm) {
        this.yhmm = yhmm;
    }

    public String getRwq() {
        return rwq;
    }

    public void setRwq(String rwq) {
        this.rwq = rwq;
    }

    public Date getZcsj() {
        return zcsj;
    }

    public void setZcsj(Date zcsj) {
        this.zcsj = zcsj;
    }

    public Date getDlsj() {
        return dlsj;
    }

    public void setDlsj(Date dlsj) {
        this.dlsj = dlsj;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getGzdw() {
        return gzdw;
    }

    public void setGzdw(String gzdw) {
        this.gzdw = gzdw;
    }

    public String getSqsm() {
        return sqsm;
    }

    public void setSqsm(String sqsm) {
        this.sqsm = sqsm;
    }

    public String getSbid() {
        return sbid;
    }

    public void setSbid(String sbid) {
        this.sbid = sbid;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYhzt() {
        return yhzt;
    }

    public void setYhzt(String yhzt) {
        this.yhzt = yhzt;
    }
}
